==> kubernetes-model-networking-6.0.0-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IngressServiceBackendFluent.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IngressServiceBackendFluent<A extends IngressServiceBackendFluent<A>> extends Fluent<A>{
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  
  /**
   * This method has been deprecated, please use method buildPort instead.
   * @return The buildable object.
   */
  @Deprecated
  public ServiceBackendPort getPort();
  public ServiceBackendPort buildPort();
  public A withPort(ServiceBackendPort port);
  public Boolean hasPort();
  public A withNewPort(String name,Integer number);
  public IngressServiceBackendFluent.PortNested<A> withNewPort();
  public IngressServiceBackendFluent.PortNested<A> withNewPortLike(ServiceBackendPort item);
  public IngressServiceBackendFluent.PortNested<A> editPort();
  public IngressServiceBackendFluent.PortNested<A> editOrNewPort();
  public IngressServiceBackendFluent.PortNested<A> editOrNewPortLike(ServiceBackendPort item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface PortNested<N> extends Nested<N>,ServiceBackendPortFluent<IngressServiceBackendFluent.PortNested<N>>{
    public N and();
    public N endPort();
    
  }
  
}

==> kubernetes-model-networking-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IngressServiceBackendFluent.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IngressServiceBackendFluent<A extends IngressServiceBackendFluent<A>> extends Fluent<A>{
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  
  /**
   * This method has been deprecated, please use method buildPort instead.
   * @return The buildable object.
   */
  @Deprecated
  public ServiceBackendPort getPort();
  public ServiceBackendPort buildPort();
  public A withPort(ServiceBackendPort port);
  public Boolean hasPort();
  public A withNewPort(String name,Integer number);
  public IngressServiceBackendFluent.PortNested<A> withNewPort();
  public IngressServiceBackendFluent.PortNested<A> withNewPortLike(ServiceBackendPort item);
  public IngressServiceBackendFluent.PortNested<A> editPort();
  public IngressServiceBackendFluent.PortNested<A> editOrNewPort();
  public IngressServiceBackendFluent.PortNested<A> editOrNewPortLike(ServiceBackendPort item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface PortNested<N> extends Nested<N>,ServiceBackendPortFluent<IngressServiceBackendFluent.PortNested<N>>{
    public N and();
    public N endPort();
    
  }
  
}
